define(["applications/nbi/js/query/elementQueryService"],
    function (queryUtils) {

        function cleanApiGroups() {
            var groups = queryUtils.findGroups();
            groups.forEach(cleanApiGroup);
        }

        function cleanApiGroup(group) {
            var rows = queryUtils.findVisibleApiRowsForGroup(group);
            var groupFromJumpTo = queryUtils.findGroupItemInJumpToMenu(group.id);
            group.style.display = rows.length > 0 ? "block" : 'none';
            groupFromJumpTo.forEach(function (item) {
                item.style.display = rows.length > 0 ? "block" : 'none';
                item.children[0].text = item.attributes.groupname.value + " (" + rows.length + ")";
            });
        }

        function applyFilter(row, uiElems) {
            var show = checkFilter(row, uiElems);
            showRow(row, show);
        }

        function checkFilter(row, uiElems) {
            var innerText = row.textContent.toLowerCase().replace(/(\r\n|\n|\r)/gm, " ").replace(/\s\s+/g, " ");
            var searchStr = uiElems.resourceSearch.value;
            var searchCheck = (searchStr == "") ? true : innerText.indexOf(searchStr.toLowerCase()) > -1;

            var aggregationValue = row.getAttribute("aggregation");
            var aggregation = uiElems.aggregationDropdown.value;
            var aggregationCheck = (aggregation === "All") ? true : aggregation === aggregationValue;

            var sortingValue = row.getAttribute("sorting");
            var sorting = uiElems.sortingDropdown.value;
            var sortingCheck = (sorting === "All") ? true : sorting === sortingValue;

            var filteringValue = row.getAttribute("filtering");
            var filtering = uiElems.filteringDropdown.value;
            var filteringCheck = (filtering === "All") ? true : filtering === filteringValue;

            var sinceVersion = row.getAttribute("sinceversion");
            var productVersion = uiElems.productVerDropdown.value;
            var productVersionCheck = (productVersion === "All") ? true : productVersion === sinceVersion;

            var modifiedVersions = row.getAttribute("modifiedversions");
            var apiVersionCheck = checkApiVersion(modifiedVersions, uiElems);
            return searchCheck && aggregationCheck && sortingCheck && filteringCheck && productVersionCheck && apiVersionCheck;
        }

        function checkApiVersion(modifiedVersions, uiElems) {
            var apiVersion = uiElems.apiVerDropdown.value;
            if (apiVersion === "All") {
                return true;
            }
            var ver = apiVersion.substr(1);
            var array = modifiedVersions.split(',');
            return array.indexOf(ver) > -1;
        }

        function showRow(elem, show) {
            elem.style.display = show ? "table-row" : 'none';
            elem.setAttribute("hidden", !show);
        }

        return {

            updateFilter: function (uiElems) {
                var list = queryUtils.findApiRows();
                list.forEach(function (row) {
                    applyFilter(row, uiElems)
                });
                cleanApiGroups();
            }
        }
    });